# Installation

You can add **FastAPI Users** to your FastAPI project in a few easy steps. First of all, install the dependency:

## With SQLAlchemy support

```sh
pip install 'fastapi-users[sqlalchemy]'
```

## With MongoDB support

```sh
pip install 'fastapi-users[mongodb]'
```

## With Tortoise ORM support

```sh
pip install 'fastapi-users[tortoise-orm]'
```

## With ormar support

```sh
pip install 'fastapi-users[ormar]'
```

---

That's it! Now, let's have a look at our [User model](./configuration/models.md).
